<?php

require_once('../model/BEUserModel.php');//any model classes being used
require_once('../model/BEPageModel.php');
require_once('../model/BEAreaModel.php');
require_once('../model/BEArticleModel.php');
require_once('../model/BETemplateModel.php');
require_once('BackLoginController.php');//any other controllers being invoked
require_once('LogoutController.php');
require_once('ManageUsersController.php');

//administration panel
//allows administrators and editors to manage the website entities
class BackEndController 
{
    //doing $this-> already makes these class level
    //but it doesn't hurt to be explicit
    private $user_model;
    private $page_model;
    private $area_model;
    private $article_model;
    private $template_model;
    
    //constructor: set up our models
    public function __construct()
    {
         $this->user_model = new BEUserModel();
         $this->page_model = new BEPageModel();
         $this->area_model = new BEAreaModel();
         $this->article_model = new BEArticleModel();
         $this->template_model = new BETemplateModel();
    }
    
    //fired on loads of admin.php
    //all get / post logic is handled here
    public function invoke()
    {
         session_start();
         //if user is signing out
         if (isset($_GET['logout']))
         {
             $logOut = new LogoutController();
             $logOut->invoke();
         }
         else{
         //if user is not yet signed in, they must sign in
         if (!isset($_SESSION['auth']))
         {
             $goLogin = new BackLoginController();
             $goLogin->invoke();
         }
         else
         {
             if ($_SESSION['auth'] == true)//they're authorized for this site
             {
                 //hold the current user as a User entity
                 $user = $this->user_model->fetchUser($_SESSION['user']);
                 $msg = "";
                 
                 //USER STUFF
                 //display users page
                 if(isset($_GET['users']))
                 {
                     if ($user->isAdmin())//only administrators can manage users
                     {
                     //was going to do them all this way
                     //but discovered everybody was still coming back to this controller via admin.php
                     $manageUsers = new ManageUsersController();
                     $manageUsers->invoke();
                     }
                     else
                         $msg = "You are not authorized to perform this action.";
                 }
                 //load form to add a new user
                 else if (isset($_GET['newuser']))
                 {
                     if ($user->isAdmin())
                     {
                     include '../view/cmanager/newuser.phtml';
                     }
                     else
                         $msg = "You are not authorized to perform this action.";
                 }
                 //finalize the new user
                 else if (isset($_POST['InsertBtn']))
                 {
                     if ($user->isAdmin())
                     {
                      //do user insert stuff
                      $this->user_model->insertUser($user->getUserName(), $_POST['username'],$_POST['password'],$_POST['first_name'],$_POST['last_name'],$_POST['email'],$_POST['is_admin'],$_POST['is_editor'],$_POST['is_author']);
            
                     //back to user mgr        
                     $manageUsers = new ManageUsersController();
                     $manageUsers->invoke();
                     }
                     else
                         $msg = "You are not authorized to perform this action.";
                 }
                 //load form to edit a user
                 else if (isset($_GET['edituser']))
                 {
                     if ($user->isAdmin())
                     {
                     $usertoedit = $this->user_model->fetchUser($_GET['edituser']);
                     include '../view/cmanager/edituser.phtml';
                     }
                     else
                         $msg = "You are not authorized to perform this action.";
                 }
                 //finalize the update for the user
                 else if (isset($_POST['EditBtn']))
                 {
                     if ($user->isAdmin())
                     {
                      //do user edit stuff
                      $this->user_model->editUser($user->getUserName(), $_POST['origuname'], $_POST['username'],$_POST['password'],$_POST['first_name'],$_POST['last_name'],$_POST['email'],$_POST['is_admin'],$_POST['is_editor'],$_POST['is_author']);
            
                     //back to user mgr        
                     $manageUsers = new ManageUsersController();
                     $manageUsers->invoke();
                     }
                     else
                         $msg = "You are not authorized to perform this action.";
                 }
                 
                 //PAGE STUFF
                 //display, um... pages page
                 else if(isset($_GET['pages']))
                 {
                     if ($user->isEditor())//only editors can manage pages
                     {
                     //get pages
                     $pages = $this->page_model->fetchAllPages();
                     
                     //show view
                     include '../view/cmanager/pagemgr.phtml';
                     }
                     else
                         $msg = "You are not authorized to perform this action.";
                 }
                 //load form to add a new page
                 else if(isset($_GET['newpage']))
                 {
                     if ($user->isEditor())
                     {
                     include '../view/cmanager/newpage.phtml';
                     }
                     else
                         $msg = "You are not authorized to perform this action.";
                 }
                 //submit new page
                 else if (isset($_POST['NewPageBtn']))
                 {
                     if ($user->isEditor())
                     {
                      //do page insert stuff
                      $this->page_model->insertPage($user->getUserName(), $_POST['name'],$_POST['alias'],$_POST['description']);
            
                     //back to page mgr        
                     //get pages
                     $pages = $this->page_model->fetchAllPages();
                     
                     //show view
                     include '../view/cmanager/pagemgr.phtml';
                     }
                     else $msg = "You are not authorized to perform this action.";
                 }
                 //load form to edit a page
                 else if (isset($_GET['editpage']))
                 {
                     if ($user->isEditor())
                     {
                     $page = $this->page_model->fetchPage($_GET['editpage']);
                     include '../view/cmanager/editpage.phtml';
                     }
                     else $msg = "You are not authorized to perform this action.";
                 }
                 //submit edited page
                 else if (isset($_POST['EditPageBtn']))
                 {
                     if ($user->isEditor())
                     {
                      //do page edit stuff
                      $this->page_model->editPage($user->getUserName(), $_POST['oname'], $_POST['name'],$_POST['alias'],$_POST['description']);
            
                     //back to page mgr        
                     //get pages
                     $pages = $this->page_model->fetchAllPages();
                     
                     //show view
                     include '../view/cmanager/pagemgr.phtml';
                     }
                     else $msg = "You are not authorized to perform this action.";
                 }
                 //load form to delete a page
                 else if (isset($_GET['deletepage']))
                 {
                     if ($user->isEditor())
                     {
                     $page = $this->page_model->fetchPage($_GET['deletepage']);
                     include '../view/cmanager/deletepage.phtml';
                     }
                     else $msg = "You are not authorized to perform this action.";
                 }
                 //submit delete confirmation, do deletion
                 else if (isset($_POST['DeletePageBtn']))
                 {
                     if ($user->isEditor())
                     {
                      //do page delete stuff
                      $this->page_model->deletePage($user->getUserName(), $_POST['name']);
            
                     //back to page mgr        
                     //get pages
                     $pages = $this->page_model->fetchAllPages();
                     
                     //show view
                     include '../view/cmanager/pagemgr.phtml';
                     }
                     else $msg = "You are not authorized to perform this action.";
                 }
                 
                 //AREA STUFF
                 //display areas
                 else if(isset($_GET['areas']))
                 {
                     if ($user->isEditor())//only editors can manage areas
                     {
                     //get areas
                     $areas = $this->area_model->fetchAllAreas();
                     
                     //show view
                     include '../view/cmanager/areamgr.phtml';
                     }
                     else $msg = "You are not authorized to perform this action.";
                 }
                 //load form to add a new area
                 else if(isset($_GET['newarea']))
                 {
                     if ($user->isEditor())
                     {
                     include '../view/cmanager/newarea.phtml';
                     }
                     else $msg = "You are not authorized to perform this action.";
                 }
                 //submit new area
                 else if (isset($_POST['NewAreaBtn']))
                 {
                     if ($user->isEditor())
                     {
                      //do page insert stuff
                      $this->area_model->insertArea($user->getUserName(), $_POST['name'],$_POST['alias'],$_POST['order'],$_POST['description']);
            
                     //back to area mgr        
                     //get areas
                     $areas = $this->area_model->fetchAllAreas();
                     
                     //show view
                     include '../view/cmanager/areamgr.phtml';
                     }
                     else $msg = "You are not authorized to perform this action.";
                 }
                 //load form to edit an area
                 else if (isset($_GET['editarea']))
                 {
                     if ($user->isEditor())
                     {
                 
                     $area = $this->area_model->fetchArea($_GET['editarea']);
                     include '../view/cmanager/editarea.phtml';
                     }
                     else $msg = "You are not authorized to perform this action.";
                 }
                 //submit edits to the area
                 else if (isset($_POST['EditAreaBtn']))
                 {
                     if ($user->isEditor())
                     {
                      //do area edit stuff
                      $this->area_model->editArea($user->getUserName(), $_POST['oname'], $_POST['name'],$_POST['alias'],$_POST['order'],$_POST['description']);
            
                     //back to area mgr        
                     //get areas
                     $areas = $this->area_model->fetchAllAreas();
                     
                     //show view
                     include '../view/cmanager/areamgr.phtml';
                     }
                     else $msg = "You are not authorized to perform this action.";
                 }
                 //load form to delete an area
                 else if (isset($_GET['deletearea']))
                 {
                     if ($user->isEditor())
                     {
                     $area = $this->area_model->fetchArea($_GET['deletearea']);
                     include '../view/cmanager/deletearea.phtml';
                     }
                     else $msg = "You are not authorized to perform this action.";
                 }
                 //confirmed; do deletion
                 else if (isset($_POST['DeleteAreaBtn']))
                 {
                     if ($user->isEditor())
                     {
                      //do page delete stuff
                      $this->area_model->deleteArea($user->getUserName(), $_POST['name']);
            
                     //back to area mgr        
                     //get areas
                     $areas = $this->area_model->fetchAllAreas();
                     
                     //show view
                     include '../view/cmanager/areamgr.phtml';
                     }
                     else $msg = "You are not authorized to perform this action.";
                 }
                 
                 //ARTICLE STUFF
                 //display articles
                 else if(isset($_GET['articles']))
                 {
                     if ($user->isEditor())//only editors can manage articles
                     {
                     //get articles
                     $articles = $this->article_model->fetchAllArticles();
                     
                     //show view
                     include '../view/cmanager/articlemgr.phtml';
                     }
                     else $msg = "You are not authorized to perform this action.";
                 }
                 //load form to add a new article
                 else if(isset($_GET['newarticle']))
                 {
                     if ($user->isEditor())
                     {
                     include '../view/cmanager/newarticle.phtml';
                     }
                     else $msg = "You are not authorized to perform this action.";
                 }
                 //submit new article
                 else if (isset($_POST['NewArticleBtn']))
                 {
                     if ($user->isEditor())
                     {
                      //do page insert stuff
                      $this->article_model->insertArticle($user->getUserName(), $_POST['name'],$_POST['title'],$_POST['description'],$_POST['page'],$_POST['area'],$_POST['body']);
            
                     //back to article mgr        
                     //get articles
                     $articles = $this->article_model->fetchAllArticles();
                     
                     //show view
                     include '../view/cmanager/articlemgr.phtml';
                     }
                     else $msg = "You are not authorized to perform this action.";
                 }
                 //load form to edit an article
                 else if (isset($_GET['editarticle']))
                 {
                     if ($user->isEditor())
                     {
                     $article = $this->article_model->fetchArticle($_GET['editarticle']);
                     include '../view/cmanager/editarticle.phtml';
                     }
                     else $msg = "You are not authorized to perform this action.";
                 }
                 //submit edited article
                 else if (isset($_POST['EditArticleBtn']))
                 {
                     if ($user->isEditor())
                     {
                      //do article edit stuff
                      $this->article_model->editArticle($user->getUserName(), $_POST['oname'], $_POST['name'],$_POST['title'],$_POST['description'],$_POST['page'],$_POST['area'],$_POST['body']);
            
                     //back to article mgr        
                     //get articles
                     $articles = $this->article_model->fetchAllArticles();
                     
                     //show view
                     include '../view/cmanager/articlemgr.phtml';
                     }
                     else $msg = "You are not authorized to perform this action.";
                 }
                 
                 //TEMPLATE STUFF
                 //show templates
                 else if(isset($_GET['templates']))
                 {
                     if ($user->isEditor())//only editors can manage templates
                     {
                     //get templates
                     $templates = $this->template_model->fetchAllTemplates();
                     
                     //show view
                     include '../view/cmanager/templatemgr.phtml';
                     }
                     else $msg = "You are not authorized to perform this action.";
                 }
                 //load form to create new template
                 else if(isset($_GET['newtemplate']))
                 {
                     if ($user->isEditor())
                     {
                     include '../view/cmanager/newtemplate.phtml';
                     }
                     else $msg = "You are not authorized to perform this action.";
                 }
                 //submit new template
                 else if (isset($_POST['NewTemplateBtn']))
                 {
                     if ($user->isEditor())
                     {
                      //do template insert stuff
                      $this->template_model->insertTemplate($user->getUserName(), $_POST['name'],$_POST['description'],$_POST['isActive'],$_POST['directives']);
            
                     //back to template mgr        
                     //get templates
                     $templates = $this->template_model->fetchAllTemplates();
                     
                     //show view
                     include '../view/cmanager/templatemgr.phtml';
                     }
                     else $msg = "You are not authorized to perform this action.";
                 }
                 //load form to edit template
                 else if (isset($_GET['edittemplate']))
                 {
                     if ($user->isEditor())
                     {
                     $template = $this->template_model->fetchTemplate($_GET['edittemplate']);
                     include '../view/cmanager/edittemplate.phtml';
                     }
                     else $msg = "You are not authorized to perform this action.";
                 }
                 //submit edited template
                 else if (isset($_POST['EditTemplateBtn']))
                 {
                     if ($user->isEditor())
                     {
                      //do template edit stuff
                      $this->template_model->editTemplate($user->getUserName(), $_POST['oname'], $_POST['name'],$_POST['description'],$_POST['isActive'],$_POST['directives']);
            
                     //back to template mgr        
                     //get templates
                     $templates = $this->template_model->fetchAllTemplates();
                     
                     //show view
                     include '../view/cmanager/templatemgr.phtml';
                     }
                     else $msg = "You are not authorized to perform this action.";
                 }
                 //load form to delete template
                 else if (isset($_GET['deletetemplate']))
                 {
                     if ($user->isEditor())
                     {
                     $template = $this->template_model->fetchTemplate($_GET['deletetemplate']);
                     include '../view/cmanager/deletetemplate.phtml';
                     }
                     else $msg = "You are not authorized to perform this action.";
                 }
                 //confirmed; do deletion
                 else if (isset($_POST['DeleteTemplateBtn']))
                 {
                     if ($user->isEditor())
                     {
                      //do page delete stuff
                      $this->template_model->deleteTemplate($user->getUserName(), $_POST['name']);
            
                     //back to template mgr        
                     //get templates
                     $templates = $this->template_model->fetchAllTemplates();
                     
                     //show view
                     include '../view/cmanager/templatemgr.phtml';
                     }
                     else $msg = "You are not authorized to perform this action.";
                 }
                 
                 //ok, just show the main page instead
                 else
                 {
                 include '../view/cmanager/main.phtml';
                 }

                 //show it if we got an error message, too
                 if ($msg != "") include '../view/cmanager/main.phtml';
                 
                 
             }
             else //not authorized
             {
                 $goLogin = new BackLoginController();
                 $goLogin->invoke();     
             }
                 
         }
         }
         
         
    }
        

}

?>
